@@ -10,14 +10,15 @@ from azure.cli.core.azclierror import (InvalidArgumentValueError, ArgumentUsageE
                                        ResourceNotFoundError, ValidationError, MutuallyExclusiveArgumentError)
 from azure.cli.core.commands.client_factory import get_mgmt_service_client, get_subscription_id
 from azure.cli.core.commands.validators import validate_tags
+from azure.mgmt.core.tools import is_valid_resource_id, parse_resource_id
 
 from knack.log import get_logger
-from msrestazure.tools import is_valid_resource_id, parse_resource_id
 
 from ._appservice_utils import _generic_site_operation
 from ._client_factory import web_client_factory
-from .utils import (_normalize_sku, get_sku_tier, _normalize_location, get_resource_name_and_group,
-                    get_resource_if_exists, is_functionapp, is_logicapp, is_webapp, is_centauri_functionapp)
+from .utils import (_normalize_sku, get_sku_tier, get_resource_name_and_group,
+                    get_resource_if_exists, is_functionapp, is_logicapp, is_webapp, is_centauri_functionapp,
+                    _normalize_location)
 
 from .aaz.latest.network import ListServiceTags
 from .aaz.latest.network.vnet import List as VNetList, Show as VNetShow
@@ -90,19 +91,20 @@ def validate_ase_create(cmd, namespace):
 
 
 def _validate_asp_sku(sku, app_service_environment, zone_redundant):
-    supported_skus = ['PREMIUMV2', 'PREMIUMV3', 'PREMIUMMV3', 'PREMIUM0V3', 'ISOLATEDV2']
+    supported_skus = ['PREMIUMV2', 'PREMIUMV3', 'PREMIUMMV3', 'PREMIUM0V3', 'ISOLATEDV2', 'ISOLATEDMV2']
     if zone_redundant and get_sku_tier(sku).upper() not in supported_skus:
         raise ValidationError("Zone redundancy cannot be enabled for sku {}".format(sku))
     # Isolated SKU is supported only for ASE
-    if sku.upper() in ['I1', 'I2', 'I3', 'I1V2', 'I2V2', 'I3V2', 'I4V2', 'I5V2', 'I6V2']:
+    if sku.upper() in ['I1V2', 'I2V2', 'I3V2', 'I4V2', 'I5V2', 'I6V2', 'I1MV2', 'I2MV2', 'I3MV2', 'I4MV2', 'I5MV2']:
         if not app_service_environment:
             raise ValidationError("The pricing tier 'Isolated' is not allowed for this app service plan. "
                                   "Use this link to learn more: "
-                                  "https://docs.microsoft.com/azure/app-service/overview-hosting-plans")
+                                  "https://learn.microsoft.com/azure/app-service/overview-hosting-plans")
     else:
         if app_service_environment:
-            raise ValidationError("Only pricing tier 'Isolated' is allowed in this app service plan. Use this link to "
-                                  "learn more: https://docs.microsoft.com/azure/app-service/overview-hosting-plans")
+            raise ValidationError("Only pricing tier 'IsolatedV2' and 'IsolatedMV2' is allowed in this "
+                                  "app service plan. Use this link to "
+                                  "learn more: https://learn.microsoft.com/azure/app-service/overview-hosting-plans")
 
 
 def validate_asp_create(namespace):
@@ -139,6 +141,7 @@ def validate_functionapp_on_containerapp_container_settings_delete(cmd, namespac
         raise ValidationError(
             "Invalid command. This is currently not supported for Azure Functions on Azure Container app environments.",
             "Please use the following command instead: az functionapp config appsettings set")
+    validate_functionapp_on_flex_plan(cmd, namespace)
 
 
 def validate_functionapp_on_containerapp_update(cmd, namespace):
@@ -159,6 +162,37 @@ def validate_functionapp_on_containerapp_site_config_show(cmd, namespace):
             "Please use the following command instead: az functionapp config container show")
 
 
+def validate_functionapp_on_flex_plan(cmd, namespace):
+    resource_group_name = namespace.resource_group_name
+    name = _get_app_name(namespace)
+    functionapp = _generic_site_operation(cmd.cli_ctx, resource_group_name, name, 'get')
+    if functionapp.server_farm_id is None:
+        return
+    parsed_plan_id = parse_resource_id(functionapp.server_farm_id)
+    client = web_client_factory(cmd.cli_ctx)
+    plan_info = client.app_service_plans.get(parsed_plan_id['resource_group'], parsed_plan_id['name'])
+    if plan_info is None:
+        raise ResourceNotFoundError('Could not determine the current plan of the functionapp')
+    if plan_info.sku.tier == 'FlexConsumption':
+        raise ValidationError('Invalid command. This is not currently supported for Azure Functions '
+                              'on the Flex Consumption plan.')
+
+
+def validate_is_flex_functionapp(cmd, namespace):
+    resource_group_name = namespace.resource_group_name
+    name = namespace.name
+    functionapp = _generic_site_operation(cmd.cli_ctx, resource_group_name, name, 'get')
+    if functionapp.server_farm_id is None:
+        raise ValidationError('This command is only valid for Azure Functions on the FlexConsumption plan.')
+    parsed_plan_id = parse_resource_id(functionapp.server_farm_id)
+    client = web_client_factory(cmd.cli_ctx)
+    plan_info = client.app_service_plans.get(parsed_plan_id['resource_group'], parsed_plan_id['name'])
+    if plan_info is None:
+        raise ResourceNotFoundError('Could not determine the current plan of the functionapp')
+    if plan_info.sku.tier.lower() != 'flexconsumption':
+        raise ValidationError('This command is only valid for Azure Functions on the FlexConsumption plan.')
+
+
 def validate_app_exists(cmd, namespace):
     app = namespace.name
     resource_group_name = namespace.resource_group_name
@@ -230,7 +264,8 @@ def validate_add_vnet(cmd, namespace):
 
     if vnet_loc != webapp_loc:
         raise ValidationError("The app and the vnet resources are in different locations. "
-                              "Cannot integrate a regional VNET to an app in a different region")
+                              "Cannot integrate a regional VNET to an app in a different region"
+                              "Web app location: {}. Vnet location: {}".format(webapp_loc, vnet_loc))
 
 
 def validate_front_end_scale_factor(namespace):
@@ -285,7 +320,7 @@ def _validate_ip_address_existence(cmd, namespace):
     scm_site = namespace.scm_site
     configs = _generic_site_operation(cmd.cli_ctx, resource_group_name, name, 'get_configuration', slot)
     access_rules = configs.scm_ip_security_restrictions if scm_site else configs.ip_security_restrictions
-    ip_exists = [(lambda x: x.ip_address == namespace.ip_address)(x) for x in access_rules]
+    ip_exists = [x.ip_address == namespace.ip_address for x in access_rules]
     if True in ip_exists:
         raise ArgumentUsageError('IP address: ' + namespace.ip_address + ' already exists. '
                                  'Cannot add duplicate IP address values.')
@@ -312,18 +347,19 @@ def _validate_service_tag_format(cmd, namespace):
         webapp = _generic_site_operation(cmd.cli_ctx, resource_group_name, name, 'get')
         service_tag_full_list = ListServiceTags(cli_ctx=cmd.cli_ctx)(command_args={
             "location": webapp.location
-        })["values"]
-        if service_tag_full_list is None:
-            logger.warning('Not able to get full Service Tag list. Cannot validate Service Tag.')
-            return
-        for tag in input_tags:
-            valid_tag = False
-            for tag_full_list in service_tag_full_list:
-                if tag.lower() == tag_full_list["name"].lower():
-                    valid_tag = True
-                    continue
-            if not valid_tag:
-                raise InvalidArgumentValueError('Unknown Service Tag: ' + tag)
+        })
+        if namespace.skip_service_tag_validation is None:
+            if service_tag_full_list is None or "values" not in service_tag_full_list:
+                logger.warning('Not able to get full Service Tag list. Cannot validate Service Tag.')
+                return
+            for tag in input_tags:
+                valid_tag = False
+                for tag_full_list in service_tag_full_list["values"]:
+                    if tag.lower() == tag_full_list["name"].lower():
+                        valid_tag = True
+                        continue
+                if not valid_tag:
+                    raise InvalidArgumentValueError('Unknown Service Tag: ' + tag)
 
 
 def _validate_service_tag_existence(cmd, namespace):
@@ -403,6 +439,10 @@ def validate_vnet_integration(cmd, namespace):
         if is_valid_resource_id(namespace.plan):
             parse_result = parse_resource_id(namespace.plan)
             plan_info = client.app_service_plans.get(parse_result['resource_group'], parse_result['name'])
+        elif _get_flexconsumption_location(namespace):
+            return
+        elif _get_consumption_plan_location(namespace):
+            raise ArgumentUsageError("Virtual network integration is not allowed for consumption plans.")
         else:
             plan_info = client.app_service_plans.get(name=namespace.plan,
                                                      resource_group_name=namespace.resource_group_name)
@@ -478,6 +518,18 @@ def _get_environment(namespace):
     return None
 
 
+def _get_flexconsumption_location(namespace):
+    if hasattr(namespace, "flexconsumption_location"):
+        return namespace.flexconsumption_location
+    return None
+
+
+def _get_consumption_plan_location(namespace):
+    if hasattr(namespace, "consumption_plan_location"):
+        return namespace.consumption_plan_location
+    return None
+
+
 def validate_app_is_webapp(cmd, namespace):
     client = web_client_factory(cmd.cli_ctx)
     name = _get_app_name(namespace)
@@ -521,11 +573,11 @@ def validate_registry_user(namespace):
     if namespace.environment and namespace.registry_username:
         if not namespace.registry_server or (not namespace.registry_password and ACR_IMAGE_SUFFIX not in namespace.registry_server):  # pylint: disable=line-too-long
             raise RequiredArgumentMissingError("Usage error: --registry-server, --registry-password and"
-                                               " --registry-username are required together if not using Azure Container Registry")
+                                               " --registry-username are required together if not using Azure Container Registry")  # pylint: disable=line-too-long
 
 
 def validate_registry_pass(namespace):
     if namespace.environment and namespace.registry_password:
         if not namespace.registry_server or (not namespace.registry_username and ACR_IMAGE_SUFFIX not in namespace.registry_server):  # pylint: disable=line-too-long
             raise RequiredArgumentMissingError("Usage error: --registry-server, --registry-password and"
-                                               " --registry-username are required together if not using Azure Container Registry")
+                                               " --registry-username are required together if not using Azure Container Registry")  # pylint: disable=line-too-long
