@@ -4,13 +4,13 @@
 # --------------------------------------------------------------------------------------------
 
 import os
-import azure.batch.models
 from azure.cli.core.util import get_file_json
 from urllib.parse import urlsplit
-
+from azure.batch.models import (DiskEncryptionTarget)
 
 # TYPES VALIDATORS
 
+
 def datetime_format(value):
     """Validate the correct format of a datetime string and deserialize."""
     from msrest.serialization import Deserializer
@@ -25,10 +25,10 @@ def datetime_format(value):
 
 def disk_encryption_target_format(value):
     """Space seperated target disks to be encrypted. Values can either be OsDisk or TemporaryDisk"""
-    if value == 'OsDisk':
-        return azure.batch.models.DiskEncryptionTarget.os_disk
-    if value == 'TemporaryDisk':
-        return azure.batch.models.DiskEncryptionTarget.temporary_disk
+    if value.lower() == 'osdisk':
+        return DiskEncryptionTarget.OS_DISK
+    if value.lower() == 'temporarydisk':
+        return DiskEncryptionTarget.TEMPORARY_DISK
     message = 'Argument {} is not a valid disk_encryption_target'
     raise ValueError(message.format(value))
 
@@ -64,6 +64,40 @@ def metadata_item_format(value):
     return {'name': data_name, 'value': data_value}
 
 
+def string_dictionary_format(values):
+    """Space-separated values in 'key=value' format."""
+    if not values:
+        raise ValueError("No values found. "
+                         "Argument values should be in the format a=b c=d")
+    result = {}
+    try:
+        for value in values.split(' '):
+            k, v = value.split('=')
+            result[k] = v
+    except ValueError:
+        message = ("Incorrectly formatted values. "
+                   "Argument values should be in the format a=b c=d")
+        raise ValueError(message)
+    return result
+
+
+def resource_tag_format(values):
+    """Space-separated values in 'key=value' format."""
+    if not values:
+        raise ValueError("No values in resource tags. "
+                         "Argument values should be in the format a=b c=d")
+    result = {}
+    try:
+        for value in values.split(' '):
+            k, v = value.split('=')
+            result[k] = v
+    except ValueError:
+        message = ("Incorrectly formatted resource tags. "
+                   "Argument values should be in the format a=b c=d")
+        raise ValueError(message)
+    return result
+
+
 def environment_setting_format(value):
     """Space-separated values in 'key=value' format."""
     try:
@@ -75,10 +109,10 @@ def environment_setting_format(value):
     return {'name': env_name, 'value': env_value}
 
 
-def application_package_reference_format(value):
+def batch_application_package_reference_format(value):
     """Space-separated application IDs with optional version in 'id[#version]' format."""
     app_reference = value.split('#', 1)
-    package = {'application_id': app_reference[0]}
+    package = {'applicationId': app_reference[0]}
     try:
         package['version'] = app_reference[1]
     except IndexError:  # No specified version - ignore
@@ -86,13 +120,7 @@ def application_package_reference_format(value):
     return package
 
 
-def certificate_reference_format(value):
-    """Space-separated certificate thumbprints."""
-    cert = {'thumbprint': value, 'thumbprint_algorithm': 'sha1'}
-    return cert
-
-
-def task_id_ranges_format(value):
+def batch_task_id_ranges_format(value):
     """Space-separated number ranges in 'start-end' format."""
     try:
         start, end = [int(i) for i in value.split('-')]
@@ -111,7 +139,7 @@ def resource_file_format(value):
         message = ("Incorrectly formatted resource reference. "
                    "Argument values should be in the format filename=httpurl")
         raise ValueError(message)
-    return {'file_path': file_name, 'http_url': http_url}
+    return {'filePath': file_name, 'httpUrl': http_url}
 
 
 # COMMAND NAMESPACE VALIDATORS
@@ -187,7 +215,7 @@ def validate_json_file(namespace):
     if namespace.json_file:
         try:
             get_file_json(namespace.json_file)
-        except EnvironmentError:
+        except OSError:
             raise ValueError("Cannot access JSON request file: " + namespace.json_file)
         except ValueError as err:
             raise ValueError(f"Invalid JSON file: {err}")
@@ -198,7 +226,7 @@ def validate_cert_file(namespace):
     try:
         with open(namespace.certificate_file, "rb"):
             pass
-    except EnvironmentError:
+    except OSError:
         raise ValueError("Cannot access certificate file: " + namespace.certificate_file)
 
 
@@ -209,14 +237,13 @@ def validate_options(namespace):
         end = namespace.end_range
     except AttributeError:
         return
-    else:
-        namespace.ocp_range = None
-        del namespace.start_range
-        del namespace.end_range
-        if start or end:
-            start = start if start else 0
-            end = end if end else ""
-            namespace.ocp_range = f"bytes={start}-{end}"
+    namespace.ocp_range = None
+    del namespace.start_range
+    del namespace.end_range
+    if start or end:
+        start = start if start else 0
+        end = end if end else ""
+        namespace.ocp_range = f"bytes={start}-{end}"
 
 
 def validate_file_destination(namespace):
@@ -225,27 +252,26 @@ def validate_file_destination(namespace):
         path = namespace.destination
     except AttributeError:
         return
-    else:
-        # TODO: Need to confirm this logic...
-        file_path = path
-        file_dir = os.path.dirname(path)
-        if os.path.isdir(path):
-            file_name = os.path.basename(namespace.file_name)
-            file_path = os.path.join(path, file_name)
-        elif not os.path.isdir(file_dir):
-            try:
-                os.mkdir(file_dir)
-            except EnvironmentError as exp:
-                message = "Directory {} does not exist, and cannot be created: {}"
-                raise ValueError(message.format(file_dir, exp))
-        if os.path.isfile(file_path):
-            raise ValueError(f"File {file_path} already exists.")
-        namespace.destination = file_path
+    # TODO: Need to confirm this logic...
+    file_path = path
+    file_dir = os.path.dirname(path)
+    if os.path.isdir(path):
+        file_name = os.path.basename(namespace.file_name)
+        file_path = os.path.join(path, file_name)
+    elif not os.path.isdir(file_dir):
+        try:
+            os.mkdir(file_dir)
+        except OSError as exp:
+            message = "Directory {} does not exist, and cannot be created: {}"
+            raise ValueError(message.format(file_dir, exp))
+    if os.path.isfile(file_path):
+        raise ValueError(f"File {file_path} already exists.")
+    namespace.destination = file_path
 
 # CUSTOM REQUEST VALIDATORS
 
 
-def validate_pool_settings(namespace, parser):
+def validate_pool_settings(namespace, _):
     """Custom parsing to enfore that either PaaS or IaaS instances are configured
     in the add pool request body.
     """
@@ -270,15 +296,7 @@ def validate_pool_settings(namespace, parser):
             if namespace.disk_encryption_targets:
                 namespace.targets = namespace.disk_encryption_targets
                 del namespace.disk_encryption_targets
-        groups = ['pool.cloud_service_configuration', 'pool.virtual_machine_configuration']
-        parser.parse_mutually_exclusive(namespace, True, groups)
 
-        paas_sizes = ['small', 'medium', 'large', 'extralarge']
-        if namespace.vm_size and namespace.vm_size.lower() in paas_sizes and not namespace.os_family:
-            message = ("The selected VM size is incompatible with Virtual Machine Configuration. "
-                       "Please swap for the equivalent: Standard_A1 (small), Standard_A2 "
-                       "(medium), Standard_A3 (large), or Standard_A4 (extra large).")
-            raise ValueError(message)
         if namespace.auto_scale_formula:
             namespace.enable_auto_scale = True
 
@@ -310,20 +328,29 @@ def validate_client_parameters(cmd, namespace):
         namespace.account_endpoint = namespace.account_endpoint.rstrip('/')
     # if account name is specified but no key, attempt to query if we use shared key auth
     if namespace.account_name and namespace.account_endpoint and not namespace.account_key:
-        if cmd.cli_ctx.config.get('batch', 'auth_mode', 'shared_key') == 'shared_key':
-            endpoint = urlsplit(namespace.account_endpoint)
-            host = endpoint.netloc
-            client = get_mgmt_service_client(cmd.cli_ctx, BatchManagementClient)
-            acc = next((x for x in client.batch_account.list()
-                        if x.name == namespace.account_name and x.account_endpoint == host), None)
-            if acc:
-                from msrestazure.tools import parse_resource_id
-                rg = parse_resource_id(acc.id)['resource_group']
-                namespace.account_key = \
-                    client.batch_account.get_keys(rg,  # pylint: disable=no-member
-                                                  namespace.account_name).primary
-            else:
-                raise ValueError(f"Batch account '{namespace.account_name}' not found.")
+
+        # check to see if we are using the default credentials
+        from azure.cli.core._profile import Profile
+        profile = Profile(cli_ctx=cmd.cli_ctx)
+        resource = cmd.cli_ctx.cloud.endpoints.batch_resource_id
+        token_credential, _, _ = profile.get_login_credentials(resource=resource)
+
+        # if not we query for the account key
+        if token_credential is None:
+            if cmd.cli_ctx.config.get('batch', 'auth_mode', 'shared_key') == 'shared_key':
+                endpoint = urlsplit(namespace.account_endpoint)
+                host = endpoint.netloc
+                client = get_mgmt_service_client(cmd.cli_ctx, BatchManagementClient)
+                acc = next((x for x in client.batch_account.list()
+                           if x.name == namespace.account_name and x.account_endpoint == host), None)
+                if acc:
+                    from azure.mgmt.core.tools import parse_resource_id
+                    rg = parse_resource_id(acc.id)['resource_group']
+                    namespace.account_key = \
+                        client.batch_account.get_keys(rg,  # pylint: disable=no-member
+                                                      namespace.account_name).primary
+                else:
+                    raise ValueError(f"Batch account '{namespace.account_name}' not found.")
     else:
         if not namespace.account_name:
             raise ValueError("Specify batch account in command line or environment variable.")
