@@ -33,7 +33,7 @@ from azure.cli.core.util import should_disable_connection_verify
 # See: https://semver.org/#is-there-a-suggested-regular-expression-regex-to-check-a-semver-string
 _semver_pattern = r"(?P<major>0|[1-9]\d*)\.(?P<minor>0|[1-9]\d*)\.(?P<patch>0|[1-9]\d*)(?:-(?P<prerelease>(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+(?P<buildmetadata>[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*))?"  # pylint: disable=line-too-long
 
-# See: https://docs.microsoft.com/azure/azure-resource-manager/templates/template-syntax#template-format
+# See: https://learn.microsoft.com/azure/azure-resource-manager/templates/template-syntax#template-format
 _template_schema_pattern = r"https?://schema\.management\.azure\.com/schemas/[0-9a-zA-Z-]+/(?P<templateType>[a-zA-Z]+)Template\.json#?"  # pylint: disable=line-too-long
 
 _bicep_diagnostic_warning_pattern = r"^([^\s].*)\((\d+)(?:,\d+|,\d+,\d+)?\)\s+:\s+(Warning)\s+([a-zA-Z-\d]+):\s*(.*?)\s+\[(.*?)\]$"  # pylint: disable=line-too-long
@@ -57,7 +57,7 @@ def validate_bicep_target_scope(template_schema, deployment_scope):
         )
 
 
-def run_bicep_command(cli_ctx, args, auto_install=True):
+def run_bicep_command(cli_ctx, args, auto_install=True, custom_env=None):
     if _use_binary_from_path(cli_ctx):
         from shutil import which
 
@@ -70,7 +70,7 @@ def run_bicep_command(cli_ctx, args, auto_install=True):
 
         _logger.debug("Using Bicep CLI from PATH. %s", bicep_version_message)
 
-        return _run_command("bicep", args)
+        return _run_command("bicep", args, custom_env)
 
     installation_path = _get_bicep_installation_path(platform.system())
     _logger.debug("Bicep CLI installation path: %s", installation_path)
@@ -93,9 +93,9 @@ def run_bicep_command(cli_ctx, args, auto_install=True):
             # Users may continue using the current installed version.
             installed_version = _get_bicep_installed_version(installation_path)
             latest_release_tag = get_bicep_latest_release_tag() if cache_expired else latest_release_tag
-            latest_version = _extract_semver(latest_release_tag)
+            latest_version = _extract_version(latest_release_tag)
 
-            if installed_version and latest_version and semver.compare(installed_version, latest_version) < 0:
+            if installed_version and latest_version and installed_version < latest_version:
                 _logger.warning(
                     'A new Bicep release is available: %s. Upgrade now by running "az bicep upgrade".',
                     latest_release_tag,
@@ -104,11 +104,12 @@ def run_bicep_command(cli_ctx, args, auto_install=True):
             if cache_expired:
                 _refresh_bicep_version_check_cache(latest_release_tag)
 
-    return _run_command(installation_path, args)
+    return _run_command(installation_path, args, custom_env)
 
 
 def ensure_bicep_installation(cli_ctx, release_tag=None, target_platform=None, stdout=True):
     system = platform.system()
+    machine = platform.machine()
     installation_path = _get_bicep_installation_path(system)
 
     if os.path.isfile(installation_path):
@@ -116,8 +117,8 @@ def ensure_bicep_installation(cli_ctx, release_tag=None, target_platform=None, s
             return
 
         installed_version = _get_bicep_installed_version(installation_path)
-        target_version = _extract_semver(release_tag)
-        if installed_version and target_version and semver.compare(installed_version, target_version) == 0:
+        target_version = _extract_version(release_tag)
+        if installed_version and target_version and installed_version == target_version:
             return
 
     installation_dir = os.path.dirname(installation_path)
@@ -132,7 +133,14 @@ def ensure_bicep_installation(cli_ctx, release_tag=None, target_platform=None, s
             else:
                 print("Installing Bicep CLI...")
         os.environ.setdefault("CURL_CA_BUNDLE", certifi.where())
-        request = urlopen(_get_bicep_download_url(system, release_tag, target_platform=target_platform))
+
+        download_url = _get_bicep_download_url(system, machine, release_tag, target_platform=target_platform)
+        _logger.debug(
+            "Generated download URL %s. from system %s, machine %s, release tag %s and target platform %s.",
+            download_url, system, machine, release_tag, target_platform,
+        )
+
+        request = urlopen(download_url)
         with open(installation_path, "wb") as f:
             f.write(request.read())
 
@@ -150,7 +158,7 @@ def ensure_bicep_installation(cli_ctx, release_tag=None, target_platform=None, s
                 "Successfully installed Bicep CLI to %s",
                 installation_path,
             )
-    except IOError as err:
+    except OSError as err:
         raise ClientRequestError(f"Error while attempting to download Bicep CLI: {err}")
 
 
@@ -170,11 +178,11 @@ def remove_bicep_installation(cli_ctx):
 
 
 def is_bicep_file(file_path):
-    return file_path.lower().endswith(".bicep")
+    return file_path.lower().endswith(".bicep") if file_path else False
 
 
 def is_bicepparam_file(file_path):
-    return file_path.lower().endswith(".bicepparam")
+    return file_path.lower().endswith(".bicepparam") if file_path else False
 
 
 def get_bicep_available_release_tags():
@@ -182,7 +190,7 @@ def get_bicep_available_release_tags():
         os.environ.setdefault("CURL_CA_BUNDLE", certifi.where())
         response = requests.get("https://aka.ms/BicepReleases", verify=_requests_verify)
         return [release["tag_name"] for release in response.json()]
-    except IOError as err:
+    except OSError as err:
         raise ClientRequestError(f"Error while attempting to retrieve available Bicep versions: {err}.")
 
 
@@ -192,7 +200,7 @@ def get_bicep_latest_release_tag():
         response = requests.get("https://aka.ms/BicepLatestRelease", verify=_requests_verify)
         response.raise_for_status()
         return response.json()["tag_name"]
-    except IOError as err:
+    except requests.RequestException as err:
         raise ClientRequestError(f"Error while attempting to retrieve the latest Bicep version: {err}.")
 
 
@@ -200,14 +208,8 @@ def bicep_version_greater_than_or_equal_to(version):
     system = platform.system()
     installation_path = _get_bicep_installation_path(system)
     installed_version = _get_bicep_installed_version(installation_path)
-    return semver.compare(installed_version, version) >= 0
-
-
-def supports_bicep_publish():
-    system = platform.system()
-    installation_path = _get_bicep_installation_path(system)
-    installed_version = _get_bicep_installed_version(installation_path)
-    return semver.compare(installed_version, "0.4.1008") >= 0
+    parsed_version = semver.VersionInfo.parse(version)
+    return installed_version >= parsed_version
 
 
 def _bicep_installed_in_ci():
@@ -256,41 +258,55 @@ def _load_bicep_version_check_result_from_cache():
             cache_expired = datetime.now() - last_check_time > _bicep_version_check_cache_ttl
 
             return latest_release_tag, cache_expired
-    except (IOError, JSONDecodeError):
+    except (OSError, JSONDecodeError):
         return None, True
 
 
-def _refresh_bicep_version_check_cache(lastest_release_tag):
+def _refresh_bicep_version_check_cache(latest_release_tag):
     with open(_bicep_version_check_file_path, "w+") as version_check_file:
         version_check_data = {
             "lastCheckTime": datetime.now().strftime(_bicep_version_check_time_format),
-            "latestReleaseTag": lastest_release_tag,
+            "latestReleaseTag": latest_release_tag,
         }
         json.dump(version_check_data, version_check_file)
 
 
 def _get_bicep_installed_version(bicep_executable_path):
     installed_version_output = _run_command(bicep_executable_path, ["--version"])
-    return _extract_semver(installed_version_output)
+    return _extract_version(installed_version_output)
 
 
-def _get_bicep_download_url(system, release_tag, target_platform=None):
-    download_url = f"https://downloads.bicep.azure.com/{release_tag}/{{}}"
+def _has_musl_library_only():
+    return os.path.exists("/lib/ld-musl-x86_64.so.1") and not os.path.exists("/lib/x86_64-linux-gnu/libc.so.6")
 
-    if target_platform:
-        executable_name = "bicep-win-x64.exe" if target_platform == "win-x64" else f"bicep-{target_platform}"
-        return download_url.format(executable_name)
 
-    if system == "Windows":
-        return download_url.format("bicep-win-x64.exe")
-    if system == "Linux":
-        if os.path.exists("/lib/ld-musl-x86_64.so.1") and not os.path.exists("/lib/x86_64-linux-gnu/libc.so.6"):
-            return download_url.format("bicep-linux-musl-x64")
-        return download_url.format("bicep-linux-x64")
-    if system == "Darwin":
-        return download_url.format("bicep-osx-x64")
+def _get_bicep_download_url(system, machine, release_tag, target_platform=None):
+    if not target_platform:
+        if system == "Windows" and machine == "arm64":
+            target_platform = "win-arm64"
+        elif system == "Windows":
+            # default to x64
+            target_platform = "win-x64"
+        elif system == "Linux" and machine == "arm64":
+            target_platform = "linux-arm64"
+        elif system == "Linux" and _has_musl_library_only():
+            # check for alpine linux
+            target_platform = "linux-musl-x64"
+        elif system == "Linux":
+            # default to x64
+            target_platform = "linux-x64"
+        elif system == "Darwin" and machine == "arm64":
+            target_platform = "osx-arm64"
+        elif system == "Darwin":
+            # default to x64
+            target_platform = "osx-x64"
+        else:
+            raise ValidationError(f'The platform "{system}" is not supported.')
 
-    raise ValidationError(f'The platform "{system}" is not supported.')
+    extension = ".exe" if target_platform.startswith("win-") else ""
+    asset_name = f"bicep-{target_platform}{extension}"
+
+    return f"https://downloads.bicep.azure.com/{release_tag}/{asset_name}"
 
 
 def _get_bicep_installation_path(system):
@@ -302,13 +318,29 @@ def _get_bicep_installation_path(system):
     raise ValidationError(f'The platform "{system}" is not supported.')
 
 
-def _extract_semver(text):
+def _extract_version(text):
     semver_match = re.search(_semver_pattern, text)
-    return semver_match.group(0) if semver_match else None
+    return semver.VersionInfo.parse(semver_match.group(0)) if semver_match else None
 
 
-def _run_command(bicep_installation_path, args):
-    process = subprocess.run([rf"{bicep_installation_path}"] + args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+def _get_bicep_env_vars(custom_env=None):
+    env_vars = (custom_env or os.environ).copy()
+
+    # See https://github.com/Azure/azure-cli/issues/29828 for background on this
+    from azure.cli.core._environment import _ENV_AZ_BICEP_GLOBALIZATION_INVARIANT
+    env_bicep_globalization_invariant = os.getenv(_ENV_AZ_BICEP_GLOBALIZATION_INVARIANT, 'False')
+
+    if env_bicep_globalization_invariant.lower() in ('true', '1'):
+        env_vars['DOTNET_SYSTEM_GLOBALIZATION_INVARIANT'] = '1'
+
+    return env_vars
+
+
+def _run_command(bicep_installation_path, args, custom_env=None):
+    process = subprocess.run(
+        [rf"{bicep_installation_path}"] + args,
+        capture_output=True,
+        env=_get_bicep_env_vars(custom_env))
 
     try:
         process.check_returncode()
