@@ -12,9 +12,8 @@ from knack.prompting import (
     prompt,
     prompt_pass
 )
-from msrestazure.tools import (
+from azure.mgmt.core.tools import (
     parse_resource_id,
-    is_valid_resource_id
 )
 from azure.cli.core import telemetry
 from azure.cli.core.commands.client_factory import get_subscription_id
@@ -26,7 +25,8 @@ from azure.cli.core.azclierror import (
 
 from ._utils import (
     run_cli_cmd,
-    get_object_id_of_current_user
+    get_object_id_of_current_user,
+    is_valid_resource_id
 )
 from ._resource_config import (
     AUTH_TYPE,
@@ -81,7 +81,7 @@ def get_resource_type_by_id(resource_id):
     '''Get source or target resource type by resource id
     '''
     target_type = None
-    all_resources = dict()
+    all_resources = {}
     all_resources.update(SOURCE_RESOURCES)
     all_resources.update(TARGET_RESOURCES)
     for _type, _id in all_resources.items():
@@ -148,7 +148,7 @@ def get_client_type(cmd, namespace):
 
         client_type = None
         try:
-            output = run_cli_cmd('az webapp show --id {} -o json'.format(source_id))
+            output = run_cli_cmd('az webapp show --id "{}" -o json'.format(source_id))
             prop = output.get('siteConfig').get('linuxFxVersion', None) or\
                 output.get('siteConfig').get('windowsFxVersion', None)
             # use 'linuxFxVersion' and 'windowsFxVersion' property to decide
@@ -158,7 +158,7 @@ def get_client_type(cmd, namespace):
             # use '*Version' property to decide
             if client_type is None:
                 for prop, _type in prop_type_map.items():
-                    if output.get('siteConfig', dict()).get(prop, None) is not None:
+                    if output.get('siteConfig', {}).get(prop, None) is not None:
                         client_type = _type
                         break
         except Exception:  # pylint: disable=broad-except
@@ -170,7 +170,7 @@ def get_client_type(cmd, namespace):
         client_type = CLIENT_TYPE.SpringBoot
         try:
             segments = parse_resource_id(source_id)
-            output = run_cli_cmd('az spring app show -g {} -s {} -n {}'
+            output = run_cli_cmd('az spring app show -g "{}" -s "{}" -n "{}"'
                                  ' -o json'.format(segments.get('resource_group'), segments.get('name'),
                                                    segments.get('child_name_1')))
             prop_val = output.get('properties')\
@@ -297,7 +297,7 @@ def opt_out_auth(namespace):
 def intelligent_experience(cmd, namespace, missing_args):
     '''Use local context and interactive inputs to get arg values
     '''
-    cmd_arg_values = dict()
+    cmd_arg_values = {}
     # use commandline source/target resource args
     for arg in missing_args:
         if getattr(namespace, arg, None) is not None:
@@ -325,7 +325,7 @@ def intelligent_experience(cmd, namespace, missing_args):
             'Auth info is not specified, use default one: --user-account')
     if cmd.cli_ctx.local_context.is_on:
         # arguments found in local context
-        context_arg_values = dict()
+        context_arg_values = {}
         for arg in missing_args:
             if arg not in cmd_arg_values:
                 if get_local_context_value(cmd, arg):
@@ -333,9 +333,9 @@ def intelligent_experience(cmd, namespace, missing_args):
 
         # apply local context arguments
         param_str = ''
-        for arg in context_arg_values:
-            option = missing_args[arg].get('options')[0]
-            value = context_arg_values[arg]
+        for k, v in context_arg_values.items():
+            option = missing_args[k].get('options')[0]
+            value = v
             param_str += '{} {} '.format(option, value)
         if param_str:
             logger.warning('Apply local context arguments: %s', param_str.strip())
@@ -422,12 +422,11 @@ def validate_target_resource_id(cmd, namespace):
     '''Validate resource id of a target resource
     '''
     if getattr(namespace, 'target_id', None):
-        if not is_valid_resource_id(namespace.target_id):
+        target = get_target_resource_name(cmd)
+        if not (target == RESOURCE.FabricSql) and not is_valid_resource_id(namespace.target_id):
             e = InvalidArgumentValueError('Resource id is invalid: {}'.format(namespace.target_id))
             telemetry.set_exception(e, 'target-id-invalid')
             raise e
-
-        target = get_target_resource_name(cmd)
         pattern = TARGET_RESOURCES.get(target)
         matched = re.match(get_resource_regex(pattern), namespace.target_id, re.IGNORECASE)
         if matched:
@@ -456,7 +455,7 @@ def get_missing_source_args(cmd, namespace):
     '''Get source resource related args
     '''
     source = get_source_resource_name(cmd)
-    missing_args = dict()
+    missing_args = {}
 
     for arg, content in SOURCE_RESOURCES_PARAMS.get(source, {}).items():
         missing_args[arg] = content
@@ -474,7 +473,7 @@ def get_missing_source_create_args(cmd, namespace):
     '''Get source resource related args in create
     '''
     source = get_source_resource_name(cmd)
-    missing_args = dict()
+    missing_args = {}
 
     args = SOURCE_RESOURCES_CREATE_PARAMS.get(source)
     if args:
@@ -489,10 +488,11 @@ def get_missing_target_args(cmd):
     '''Get target resource related args
     '''
     target = get_target_resource_name(cmd)
-    missing_args = dict()
+    missing_args = {}
 
-    for arg, content in TARGET_RESOURCES_PARAMS.get(target).items():
-        missing_args[arg] = content
+    if target in TARGET_RESOURCES_PARAMS:
+        for arg, content in TARGET_RESOURCES_PARAMS.get(target).items():
+            missing_args[arg] = content
 
     return missing_args
 
@@ -502,7 +502,7 @@ def get_missing_auth_args(cmd, namespace):
     '''
     source = get_source_resource_name(cmd)
     target = get_target_resource_name(cmd)
-    missing_args = dict()
+    missing_args = {}
 
     # check if there are auth_info related params
     auth_param_exist = False
@@ -512,6 +512,8 @@ def get_missing_auth_args(cmd, namespace):
                 auth_param_exist = True
                 break
 
+    if target == RESOURCE.ConfluentKafka:
+        return missing_args
     # when keyvault csi is enabled, auth_type is userIdentity without subs_id and client_id
     if source == RESOURCE.KubernetesCluster and target == RESOURCE.KeyVault:
         if getattr(namespace, 'enable_csi', None):
@@ -549,7 +551,7 @@ def get_missing_auth_args(cmd, namespace):
 def get_missing_connection_name(namespace):
     '''Get connection_name arg if user didn't provide it in command line
     '''
-    missing_args = dict()
+    missing_args = {}
     if getattr(namespace, 'connection_name', None) is None:
         missing_args['connection_name'] = {
             'help': 'The connection name',
@@ -562,7 +564,7 @@ def get_missing_connection_name(namespace):
 def get_missing_client_type(namespace):
     '''Get client_type arg if user didn't provide it in command line
     '''
-    missing_args = dict()
+    missing_args = {}
     if getattr(namespace, 'client_type', None) is None:
         missing_args['client_type'] = {
             'help': 'Client type of the connection',
@@ -575,7 +577,7 @@ def get_missing_client_type(namespace):
 def validate_local_default_params(cmd, namespace):  # pylint: disable=unused-argument
     '''Get missing args of local connection command
     '''
-    missing_args = dict()
+    missing_args = {}
 
     if getattr(namespace, 'id', None):
         namespace.id = namespace.id.lower()
@@ -608,7 +610,7 @@ def apply_local_default_params(cmd, namespace, arg_values):  # pylint: disable=u
 
 
 def validate_local_list_params(cmd, namespace):  # pylint: disable=unused-argument
-    missing_args = dict()
+    missing_args = {}
     if getattr(namespace, 'resource_group', None) is None:
         missing_args.update(LOCAL_CONNECTION_PARAMS.get("resource_group"))
     return missing_args
@@ -617,7 +619,7 @@ def validate_local_list_params(cmd, namespace):  # pylint: disable=unused-argume
 def validate_list_params(cmd, namespace):
     '''Get missing args of list command
     '''
-    missing_args = dict()
+    missing_args = {}
     if not validate_source_resource_id(cmd, namespace):
         missing_args.update(get_missing_source_args(cmd, namespace))
     return missing_args
@@ -626,7 +628,7 @@ def validate_list_params(cmd, namespace):
 def validate_create_params(cmd, namespace):
     '''Get missing args of create command
     '''
-    missing_args = dict()
+    missing_args = {}
     if not validate_source_resource_id(cmd, namespace):
         missing_args.update(get_missing_source_args(cmd, namespace))
     missing_args.update(get_missing_source_create_args(cmd, namespace))
@@ -640,7 +642,7 @@ def validate_create_params(cmd, namespace):
 def validate_local_create_params(cmd, namespace):
     '''Get missing args of create command
     '''
-    missing_args = dict()
+    missing_args = {}
 
     if not validate_target_resource_id(cmd, namespace):
         missing_args.update(get_missing_target_args(cmd))
@@ -651,7 +653,7 @@ def validate_local_create_params(cmd, namespace):
 def validate_addon_params(cmd, namespace):
     '''Get missing args of add command with '--new'
     '''
-    missing_args = dict()
+    missing_args = {}
     if not validate_source_resource_id(cmd, namespace):
         missing_args.update(get_missing_source_args(cmd, namespace))
     missing_args.update(get_missing_auth_args(cmd, namespace))
@@ -661,8 +663,8 @@ def validate_addon_params(cmd, namespace):
 def validate_update_params(cmd, namespace):
     '''Get missing args of update command
     '''
-    missing_args = dict()
-    if not validate_connection_id(namespace):
+    missing_args = {}
+    if not validate_connection_id(namespace) and not validate_source_resource_id(cmd, namespace):
         missing_args.update(get_missing_source_args(cmd, namespace))
     # missing_args.update(get_missing_auth_args(cmd, namespace))
     missing_args.update(get_missing_connection_name(namespace))
@@ -672,7 +674,7 @@ def validate_update_params(cmd, namespace):
 def validate_local_update_params(cmd, namespace):  # pylint: disable=unused-argument
     '''Get missing args of update command
     '''
-    missing_args = dict()
+    missing_args = {}
     # missing_args.update(get_missing_auth_args(cmd, namespace))
     return missing_args
 
@@ -680,7 +682,7 @@ def validate_local_update_params(cmd, namespace):  # pylint: disable=unused-argu
 def validate_default_params(cmd, namespace):
     '''Get missing args of commands except for list, create
     '''
-    missing_args = dict()
+    missing_args = {}
     if not validate_connection_id(namespace):
         missing_args.update(get_missing_source_args(cmd, namespace))
     missing_args.update(get_missing_connection_name(namespace))
@@ -770,7 +772,7 @@ def apply_auth_args(cmd, namespace, arg_values):
 
 
 def apply_workload_identity(namespace, arg_values):
-    output = run_cli_cmd('az identity show --ids {}'.format(
+    output = run_cli_cmd('az identity show --ids "{}"'.format(
         arg_values.get('workload_identity_auth_info')
     ))
     if output:
@@ -905,7 +907,7 @@ def validate_params(cmd, namespace):
             namespace.connection_name = generate_connection_name(cmd)
         else:
             validate_connection_name(namespace.connection_name)
-        if getattr(namespace, 'new_addon'):
+        if getattr(namespace, 'new_addon', None):
             _validate_and_apply(validate_addon_params, apply_addon_params)
         else:
             _validate_and_apply(validate_create_params, apply_create_params)
@@ -943,25 +945,43 @@ def validate_kafka_params(cmd, namespace):
 def validate_service_state(linker_parameters):
     '''Validate whether user provided params are applicable to service state
     '''
-    target_type = None
-    target_id = linker_parameters.get('target_service', dict()).get('id')
+    target_type = linker_parameters.get('target_service', {}).get('type')
+
+    # AzureResource and other types (e.g., FabricResource, SelfHostedResource)
+    if target_type == "AzureResource":
+        target_id = linker_parameters.get('target_service', {}).get('id')
+    else:
+        target_id = linker_parameters.get('target_service', {}).get('endpoint')
+
     for target, resource_id in TARGET_RESOURCES.items():
         matched = re.match(get_resource_regex(resource_id), target_id, re.IGNORECASE)
         if matched:
             target_type = target
 
-    if target_type == RESOURCE.AppConfig and linker_parameters.get('auth_info', dict()).get('auth_type') == 'secret':
+    if target_type == RESOURCE.AppConfig and linker_parameters.get('auth_info', {}).get('auth_type') == 'secret':
         segments = parse_resource_id(target_id)
         rg = segments.get('resource_group')
         name = segments.get('name')
+        sub = segments.get('subscription')
         if not rg or not name:
             return
 
-        output = run_cli_cmd('az appconfig show -g {} -n {}'.format(rg, name))
+        output = run_cli_cmd('az appconfig show -g "{}" -n "{}" --subscription "{}"'.format(rg, name, sub))
         if output and output.get('disableLocalAuth') is True:
             raise ValidationError('Secret as auth type is not allowed when local auth is disabled for the '
                                   'specified appconfig, you may use service principal or managed identity.')
 
+    if target_type == RESOURCE.Redis:
+        auth_type = linker_parameters.get('auth_info', {}).get('auth_type')
+        if auth_type == AUTH_TYPE.Secret.value or auth_type == AUTH_TYPE.SecretAuto.value:
+            return
+        redis = run_cli_cmd('az redis show --ids "{}"'.format(target_id))
+        if redis.get('redisConfiguration', {}).get('aadEnabled', 'False') != "True":
+            raise ValidationError('Please enable Microsoft Entra Authentication on your Redis first. '
+                                  'Note that it will cause your cache instances to reboot to load new '
+                                  'configuration and result in a failover. Consider performing the '
+                                  'operation during low traffic or outside of business hours.')
+
 
 def get_default_object_id_of_current_user(cmd, namespace):  # pylint: disable=unused-argument
     user_account_auth_info = getattr(namespace, 'user_account_auth_info', None)
